@@ -1,6 +1,6 @@
 /* 
  * i-scream central monitoring system
- * http://www.i-scream.org.uk
+ * http://www.i-scream.org
  * Copyright (C) 2000-2002 i-scream
  * 
  * This program is free software; you can redistribute it and/or
@@ -170,24 +170,6 @@ void log_msg(int level, char *format, ...){
 	}
 }
 
-/* Takes many pointers, checks if they are NULL or not, and then free's them */
-/* Deprciated - and i only wrote it today! :)
-void m_free(int num_pointers, ...){
-	int x=0;
-	va_list ap;
-	void *p;
-
-	va_start(ap, num_pointers);
-	for(;x<num_pointers;x++){
-		p=va_arg(ap, void*);
-		if(p!=NULL){
-			free(p);
-		}
-	}
-	va_end(ap);
-}
-*/
-
 int create_udp_sockinfo(udp_sockinfo_t *udp_sockinfo, char *hostname, int port){
 
 	struct in_addr haddr;
@@ -387,7 +369,6 @@ int ihost_getconfig(ihost_state_t *ihost_state){
                         goto error;
                 }
 
-		printf("string : %s\n", response_ptr);
 	        server_udp_port=atoi(response_ptr);
 
 		if (server_udp_port==0){
@@ -712,14 +693,18 @@ too_big_error:
 
 	
 void usage(char *progname){
-        fprintf(stderr, "Usage %s [options] server port\n", progname);
-        fprintf(stderr, "Options\n");
-        fprintf(stderr, "  -v           Verbose mode,-vv would make even more verbose\n");
-        fprintf(stderr, "  -f           Foreground mode, print errors to stderr\n");
-	fprintf(stderr, "  -s		Set the machine name to be reported as\n");
-	fprintf(stderr, "  -i		Set the IP to be reported as\n");
-        fprintf(stderr, "  -V           Print version number\n");
-        fprintf(stderr, "  -h           Prints this help page\n");
+        fprintf(stderr, "Usage %s [-v[v]] [-f] [-n name] [-i ip] [-s server] [-p port] [-V] [-h]\n\n", progname);
+        fprintf(stderr, "  -v    Verbose mode, -vv would make even more verbose\n");
+        fprintf(stderr, "  -f    Foreground mode, print errors to stderr\n");
+	fprintf(stderr, "  -n    Set the machine name to be reported as\n");
+	fprintf(stderr, "  -i    Set the IP to be reported as\n");
+	fprintf(stderr, "  -s    Specifies the i-scream server to connect to\n");
+	fprintf(stderr, "          default: %s\n", DEF_SERVER_NAME);
+	fprintf(stderr, "  -p    Specifies the i-scream server port\n");
+	fprintf(stderr, "          default: %d\n", DEF_SERVER_PORT);
+        fprintf(stderr, "  -V    Print version number\n");
+        fprintf(stderr, "  -h    Prints this help page\n");
+	fprintf(stderr, "\nReport bugs to <%s>.\n", PACKAGE_BUGREPORT);
         exit(1);
 }
 
@@ -746,7 +731,8 @@ int main(int argc, char **argv){
 	ihost_config.log=stderr;
 
 	/* Blank ihost_state to default settings */
-	ihost_state.filtermanager_host=NULL;
+	ihost_state.filtermanager_host=DEF_SERVER_NAME;
+	ihost_state.filtermanager_port=DEF_SERVER_PORT;
 	ihost_state.host_fqdn=NULL;
 	ihost_state.host_ip=NULL;
 	ihost_state.preset_fqdn = 0;
@@ -755,7 +741,7 @@ int main(int argc, char **argv){
 	ihost_state.file_list=NULL;
 	ihost_state.last_modified=NULL;
 
-        while((cmdopt=getopt(argc, argv, "vfhVs:i:")) != -1){
+        while((cmdopt=getopt(argc, argv, "vfVn:i:s:p:h")) != -1){
                 switch(cmdopt){
                         case 'v':
                                 ihost_config.verbose++;
@@ -766,14 +752,10 @@ int main(int argc, char **argv){
                                 ihost_config.daemon=0;
                                 break;
 
-                        case 'h':
-                                usage(argv[0]);
-                                break;
-
                         case 'V':
                                 fprintf(stderr, "%s version %s\n", argv[0], VERSION);
                                 break;
-			case 's':
+			case 'n':
 				ihost_state.preset_fqdn = 1;
 				ihost_state.host_fqdn = strdup(optarg);
 				if(ihost_state.host_fqdn == NULL){
@@ -791,20 +773,21 @@ int main(int argc, char **argv){
 				}
 				break;
 
+			case 's':
+				ihost_state.filtermanager_host=strdup(optarg);
+				break;
+
+			case 'p':
+				ihost_state.filtermanager_port=atoi(optarg);
+				break;
+
+                        case 'h':
                         default:
                                 usage(argv[0]);
                                 exit(1);
                 }
         }
 
-        if(argc!=optind+2){
-                usage(argv[0]);
-                exit(1);
-        }
-
-	ihost_state.filtermanager_host=strdup(argv[optind]);
-	ihost_state.filtermanager_port=atoi(argv[optind+1]);
-	
 	if(gethostbyname(ihost_state.filtermanager_host)==NULL){
 		log_msg(LOG_CRIT, "Failed to lookup hostname. Please check settings");
 		exit(1);
@@ -841,7 +824,13 @@ int main(int argc, char **argv){
 
         }
 
-	log_msg(LOG_INFO, "Starting ihost");
+	log_msg(LOG_INFO, "Starting ihost...");
+
+	log_msg(LOG_DEBUG, "Running statgrab_init()");
+	if(statgrab_init()){
+		log_msg(LOG_CRIT, "statgrab_init failed (%m)");
+		exit(1);
+	}
 	
         log_msg(LOG_DEBUG,"Writing PID FILE");
 
@@ -869,7 +858,6 @@ int main(int argc, char **argv){
 		sleep(10);
 	}
 
-	printf("%s\n%d\n", ihost_state.server_fqdn, ihost_state.server_udp_port);
 	while((create_udp_sockinfo(&udp_sockinfo, ihost_state.server_fqdn, ihost_state.server_udp_port))!=0){
 		log_msg(LOG_ERR, "Failed to create udp socket");	
 		sleep(10);
